@@ -112,15 +112,20 @@ class apic():
 		except KeyError:
 			return None
 
-	def getTemplateId(self, templateName):
+
+	def getTemplates(self):
 		url = "https://" + self.ip + ":" + self.port + baseurl + "template-programmer/project"
 		payload = {}
 		headers = {
 		'x-auth-token': self.authToken
 		}
 		response = requests.request("GET", url, headers=headers, data = payload, verify=verifySSL, timeout=timeout)
-		data = json.loads(response.text)	
+		data = json.loads(response.text)
+		
+		return data
 
+	def getTemplateId(self, templateName):
+		data = self.getTemplates()
 		for projects in data:
 			for templates in projects['templates']:
 				try:
