@@ -162,13 +162,20 @@ class device():
 						self.deploymentId = deploymentId
 						return {"deploymentId":deploymentId}
 				except:
-					return None
+					return result
 
 	def deployTemplateStatus(self, **kwargs):
 		try:
 			self.deploymentId = kwargs['id']
 		except:
 			pass
+
+		if self.deploymentId == None:
+			data = {}
+			data['status'] = 'unknown'
+			data['message'] = 'no deployment id'
+			return data
+
 		url = "https://" + self.dnac.ip + ":" + self.dnac.port + "/dna/intent/api/v1/template-programmer/template/deploy/status/" + self.deploymentId
 		payload = {}
 		headers = {
@@ -178,8 +185,10 @@ class device():
 		response = requests.request("GET", url, headers=headers, json=payload, verify=verifySSL, timeout=timeout)
 
 		data = json.loads(response.text)
-		return data['status']
-
+		if 'status' in data:
+			return data['status']
+		else:
+			return data
 
 	def deployTemplateReport(self, deploymentId):
 		try:
